xbox.auxiliary package
======================

Subpackages
-----------

.. toctree::

    xbox.auxiliary.scripts

Submodules
----------

.. toctree::

   xbox.auxiliary.crypto
   xbox.auxiliary.manager
   xbox.auxiliary.packer
   xbox.auxiliary.packet
   xbox.auxiliary.relay

Module contents
---------------

.. automodule:: xbox.auxiliary
    :members:
    :undoc-members:
    :show-inheritance:
